import(stats)
import(graphics)
importFrom(utils, install.packages)
import(methods)
importFrom(multcomp, contrMat, glht, mcp)
importFrom(multtest, MTP, mt.rawp2adjp, fwer2fdr, fwer2tppfp, fwer2gfwer)
importFrom(plotrix, plotCI)
importFrom(mvtnorm, pmvt, qmvnorm, qmvt, pmvnorm)
export(augmentation)
export(compareMutoss)
export(mu.compare.adjusted)
export(mu.compare.critical)
export(mu.compare.summary)
export(fisher23.marginal)
export(fisher23_fast)
export(fisher22.marginal)
export(fisher22_fast)
export(gao)
export(requireLibrary)
export(hommel)
export(oracleBH)
export(Qvalue)
export(BlaRoq)
export(pval2qval)
export(pval2locfdr)
export(linearStepUp)
export(two.stage)
export(multiple.down.adjust)
export(multiple.down)
export(multcomp.wrapper)
export(onesamp.marginal)
export(paired.marginal)
export(twosamp.marginal)
export(ftest.marginal)
export(mutoss.apply)
exportClasses(ErrorControl)
exportClasses(Mutoss)
export(mutoss.plotCI)
export(gatherParameters)
export(gatherStatistics)
export(simulation)
export(nparcomp)
export(nparcomp.wrapper)
export(storey_pi0_est)
export(ABH_pi0_est)
export(TSBKY_pi0_est)
export(BR_pi0_est)
export(ranktruncated)
export(regwq)
export(snk)
export(printRejected)
export(rom)
export(holm)
export(calculateBetaAdjustment)
export(aorc)
export(BL)
export(BH)
export(BY)
export(hochberg)
export(adaptiveBH)
export(adaptiveSTS)
export(SidakSD)
export(indepBR)
export(twostageBR)
export(SUD)
export(SD)
export(SU)
export(pValuesPlot)
export(adjPValuesPlot)
export(tukey.wrapper)
export(bonferroni)
export(sidak)
export(twosamp.model)
export(paired.model)
export(onesamp.model)
export(ftest.model)
export(fisher23.model)
export(fisher22.model)
export(jointCDF.orderedUnif)