\name{pValuesPlot}
\alias{pValuesPlot}
\title{A function plotting p-values...}
\usage{pValuesPlot(pValues)}
\description{A function plotting p-values}
\author{MarselScheer}
\arguments{\item{pValues}{A numeric containing the pValues to plot.}}
