\name{mutoss.plotCI}
\alias{mutoss.plotCI}
\title{mutoss.plotCI}
\usage{mutoss.plotCI(mat)}
\description{Plots the confidence intervals}
\arguments{\item{mat}{Matrix containing the confidence interval limits. TODO specify the matrix layout.}}
